distributed

package
v0.0.0-...-3985dbb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 22, 2016 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DistributedOption

type DistributedOption struct {
	Master       string
	DataCenter   string
	Rack         string
	TaskMemoryMB int
	FlowBid      float64
	Module       string
	Host         string
	Port         int
}

func Option

func Option() *DistributedOption

func (*DistributedOption) GetFlowRunner

func (o *DistributedOption) GetFlowRunner() flow.FlowRunner

func (*DistributedOption) SetDataCenter

func (o *DistributedOption) SetDataCenter(dataCenter string) *DistributedOption

func (*DistributedOption) SetMaster

func (o *DistributedOption) SetMaster(master string) *DistributedOption

type DistributedPlanner

type DistributedPlanner struct {
}

func Planner

func Planner() *DistributedPlanner

func (*DistributedPlanner) GetFlowRunner

func (o *DistributedPlanner) GetFlowRunner() flow.FlowRunner

func (*DistributedPlanner) RunFlowContext

func (fcd *DistributedPlanner) RunFlowContext(fc *flow.FlowContext)

driver runs on local, controlling all tasks

Directories

Path Synopsis
Package agent runs on servers with computing resources, and executes tasks sent by driver.
Package agent runs on servers with computing resources, and executes tasks sent by driver.
Package driver coordinates distributed execution.
Package driver coordinates distributed execution.
scheduler
Schedule tasks to run on available resources assigned by master.
Schedule tasks to run on available resources assigned by master.
Package master collects data from agents, and manage named network channels.
Package master collects data from agents, and manage named network channels.
ui
Package netchan creates network channels.
Package netchan creates network channels.
Package rsync adds file server and copying client to copy files between glow driver and agent.
Package rsync adds file server and copying client to copy files between glow driver and agent.
Disk-backed queue
Disk-backed queue

Jump to